let mapMain, mapView;

require([
  "esri/Map",
  "esri/views/MapView",

  "esri/geometry/Extent",

  "esri/layers/MapImageLayer",
  "esri/layers/FeatureLayer",

  "esri/widgets/ScaleBar",
  "esri/widgets/LayerList",

], function (
  Map,
  MapView,

  Extent,

  MapImageLayer,
  FeatureLayer,

  ScaleBar,
  LayerList,
) {

    // Map クラスの作成
    mapMain = new Map({
      basemap: "satellite"
    });

    /*
      ステップ：初期表示範囲を指定します
      注意：実際の座標値はスニペットのものと完全には一致しません
    */
    const initExtent = new Extent({
      "spatialReference": {
        "latestWkid": 3857,
        "wkid": 102100
      },
      "xmin": -9837430.694532482,
      "ymin": 5108123.946065974,
      "xmax": -9781975.630511662,
      "ymax": 5145272.34181252
    });


    // MapView クラスの作成
    mapView = new MapView({
      container: "cpCenter",
      map: mapMain,
      extent: initExtent,
      zoom:15

    });

    /*
      ステップ：マップに USA マップ サービスを追加します
    */
    const lyrUSA = new MapImageLayer({
      url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/USA/MapServer",
      opacity: 0.5
    });
    mapMain.add(lyrUSA);

    /*
      ステップ：マップに Service Requests レイヤーを追加します
    */
    const lyrRequests = new FeatureLayer({
      url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/ServiceRequest/FeatureServer/0",
      definitionExpression: "status='Unassigned'"
    });
    mapMain.add(lyrRequests);

    /*
      ステップ：アプリケーションに ScaleBar ウィジェットを追加します
    */
    const scaleBar = new ScaleBar({
      view: mapView,
      unit: "dual"
    });
    mapView.ui.add(scaleBar, "bottom-left");

    /*
      ステップ：アプリケーションに LayerList ウィジェットを追加します
    */
    const layerList = new LayerList({
      view: mapView,
      container: "divLayerList"
    });


  });