require([
  "esri/Map",
  "esri/views/MapView",

  "esri/layers/FeatureLayer",

  "esri/widgets/Editor",

  "esri/widgets/Sketch/SketchViewModel",

  "esri/widgets/FeatureTemplates",

], function (
  Map,
  MapView,

  FeatureLayer,

  Editor,

  SketchViewModel,

  FeatureTemplates
) {

    // Map クラスの作成
    const mapMain = new Map({
      basemap: "topo-vector"
      
    });

    // MapView クラスの作成
    const mapView = new MapView({
      map: mapMain,
      container: "mapViewDiv",
      center: [-116.64, 34.37],
      zoom: 10
    });

    /*
      ステップ：編集可能なレイヤーの構築、追加
    */
    const flFirePoints = new FeatureLayer({
      url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/Wildfire/FeatureServer/0",
      outFields: ["*"]
    });
    const flFireLines = new FeatureLayer({
      url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/Wildfire/FeatureServer/1",
      outFields: ["*"]
    });
    const flFirePolygons = new FeatureLayer({
      url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/Wildfire/FeatureServer/2",
      outFields: ["*"]
    });
    mapMain.addMany([flFirePoints, flFireLines, flFirePolygons]);

    /*
      ステップ：Editor ウィジェットの作成
    */
    const editor = new Editor({
      view: mapView,
      snappingOptions:{
        enabled: true,
      }
    });
    mapView.ui.add(editor, "top-right");

    /*
      ステップ：FeatureTemplates の作成
    */
    const featureTemplates = new FeatureTemplates({
      layers: [flFirePoints, flFireLines, flFirePolygons]
    });
    mapView.ui.add(featureTemplates, "top-left");
    featureTemplates.on("select", selectTemplate);

    // SketchViewModel の初期化
    const sketchVM = new SketchViewModel({
      layer: mapView.graphics,
      view: mapView,
      snappingOptions:{
        enabled: true,
      }
    });
    sketchVM.on("create", editFeature);

    // FeatureTemplates の選択内容を入力する変数
    let currentAttributes, currentFeatureLayer;

    function selectTemplate(evt) {
      // 選択内容の格納
      currentAttributes = evt.template.prototype.attributes;
      currentFeatureLayer = evt.item.layer;

      // スケッチの開始
      sketchVM.create(currentFeatureLayer.geometryType, { mode: "click" });

    }

    function editFeature(evt) {
      // 作図の完了をハンドリング
      if (evt.state === "complete") {
        // 作図結果をグラフィックをグラフィックス レイヤーから削除
        mapView.graphics.remove(evt.graphic);
        /*
          ステップ：作図結果とテンプレートの選択内容からグラフィックを作成
        */
        const editGraphic = evt.graphic;
        editGraphic.attributes = currentAttributes;

        /*
          ステップ：グラフィックをフィーチャ レイヤーに追加
        */
        currentFeatureLayer.applyEdits({
          addFeatures: [editGraphic]
        });

      }
    }

  });

