require([
  "esri/Map",
  "esri/views/MapView",

  "esri/layers/FeatureLayer",


], function(
  Map,
  MapView,

  FeatureLayer,

) {

  // アプリケーションに配置される button 要素の click イベントのハンドリング
  const sketchBtn = document.getElementById("sketchBtn");
  sketchBtn.addEventListener("click", drawPolygon);
  const resetBtn = document.getElementById("resetBtn");
  resetBtn.addEventListener("click", resetTable);


  // Map クラスの作成
  const mapMain = new Map({
      basemap: "gray-vector"
  });

  // MapView クラスの作成
  const mapView = new MapView({
      map: mapMain,
      container: "divMap",
      center: [139, 35],
      zoom: 2,
      // ハイライトとして使用する色の設定
      highlightOptions: {
          color: "#ffea00"
      }
  });

  // スケッチの開始ボタンの配置
  mapView.ui.add(sketchBtn, "bottom-left");

  // 出力フィールドの指定
  const outFieldsPoints = ["OBJECTID", "NAME", "COUNTRY", "POPULATIONCLASS"];

  // FeatureLayer（ポイント）へのシンボルの設定
  const markerSym = {
      type: "simple-marker",
      style: "square",
      color: "#d90909",
      size: "6px",
      outline: null
  }

  const renderer = {
      type: "simple",
      symbol: markerSym
  }

  // SampleWorld レイヤーの作成
  const lyrPoints = new FeatureLayer({
      url: "https://services.arcgis.com/wlVTGRSYTzAbjjiC/arcgis/rest/services/SampleWorld/FeatureServer/0",
      renderer: renderer,
      outFields: outFieldsPoints
  });
  mapMain.addMany([lyrPoints]);

  /*
    ステップ：FeatureTable の追加
  */


  /*
    ステップ：SketchViewModel の初期化
  */


  function drawPolygon() {
      // ボタン要素の属性を修正し、選択不可状態に設定
      sketchBtn.disabled = "true";

      /*
        ステップ：SketchViewModel の開始
      */

  }

  // FeatureLayerView の監視
  let featureLayerView;
  /*
    ステップ：FeatureLayerView の生成をキャッチ
  */


  function queryPoints(geometryInput) {

      /*
        ステップ：Query の初期化
      */


      /*
        ステップ：検索の実行、完了のハンドリング
      */

  }

  // ハイライト状態の監視
  let highlightHandler;

  function displayQueryResult(results) {
      // ハイライトがすでに作成済みの場合、ハイライト内容を初期化
      if (highlightHandler) {
          highlightHandler.remove();
      }

      /*
        ステップ：テーブルにすでに選択済みのデータがある場合、選択内容を初期化
      */
      // if(featureTable.highlightIds){
      //    featureTable.highlightIds.removeAll();
      // }

      // ハイライトするフィーチャが存在する場合のみ実行
      if (results.features.length > 0) {
          /*
            ステップ：検索結果を使用して図形をハイライト
          */


          /*
          ステップ：検索結果を利用してデータを選択
          */


          /*
          ステップ：選択したデータのみをテーブルに表示
          */


          // ボタン要素の属性を修正し、選択可能状態に設定
          sketchBtn.disabled = "false";
          // スケッチ結果の削除
          mapView.graphics.removeAll();

      } else {
          // ボタン要素の属性を修正し、選択可能状態に設定
          sketchBtn.disabled = "false";
          // スケッチ結果の削除
          mapView.graphics.removeAll();
      }

  }

  // 結果のリセットおよび初期化
  mapView.ui.add(resetBtn, "bottom-left");

  function resetTable(){
    featureTable.highlightIds.removeAll();
    featureTable.clearSelectionFilter();
    featureTable.filterGeometry = lyrPoints.fullExtent
    highlightHandler.remove();
  }

});