require([
  "esri/Map",
  "esri/views/SceneView",

  "esri/geometry/Point",
  "esri/Graphic",

], function (
  Map,
  SceneView,

  Point,
  Graphic,

) {

    // Calcite Web を使用した DOM 要素
    const processLoader = document.getElementById("processLoader");
    const errorPanel = document.getElementById("errorPanel");

    // Map クラスの作成
    const mapMain = new Map({
      basemap: "hybrid",
      ground: "world-elevation"
    });

    // SceneView クラスの作成
    const sceneView = new SceneView({
      map: mapMain,
      container: "sceneViewDiv",
      camera: {
        position: [137.8506, 36.5, 5000],
        tilt: 70
      }
    });
    // エラー通知の表示位置を指定（CSS で display="none" と設定しているため、画面には表示されません）
    sceneView.ui.add(errorPanel, "bottom");

    // 観測点を描画するためのマーカー シンボル
    const markerSym = {
      type: "simple-marker",
      size: "14px",
      color: [240, 145, 153],
      outline: null
    }

    // 結果を描画するためのポリゴン シンボル
    const fillSym = {
      type: "simple-fill",
      color: [255, 255, 0, 0.5],
      outline: null
    }

    /*
      ステップ：ジオプロセッサの準備
    */


    /*
      ステップ：空間参照の設定
    */


    // シーンのクリックで観測点の追加 / ジオプロセッサの実行
    sceneView.on("click", executeViewshedTask);

    function executeViewshedTask(evt) {
      // グラフィックス レイヤーの初期化
      sceneView.graphics.removeAll();

      // クリック地点の情報から、ジオメトリを作成
      const pointGeom = new Point({
        longitude: evt.mapPoint.longitude,
        latitude: evt.mapPoint.latitude
      });
      // 観測点をシーンに追加
      const inputPoint = new Graphic({
        geometry: pointGeom,
        symbol: markerSym
      });
      sceneView.graphics.add(inputPoint);

      /*
        ステップ：1 つ目の入力パラメーターの準備
      */


      /*
        ステップ：2 つ目の入力パラメーターの準備
      */


      /*
        ステップ：JSON 形式のオブジェクトでジオプロセッサの入力パラメーターを作成
      */


      /*
        ステップ：ローディング パネルの表示
      */
      // processLoader.style.display = "inline";

      /*
        ステップ：ジオプロセッサの実行
      */


    }

    function drawResult(gpResults) {
      /*
        ステップ：結果からフィーチャの配列を取得
      */


      /*
        ステップ：結果をループして各フィーチャにシンボルを定義して追加
      */


      // 検索結果にズーム
      sceneView.goTo({
        target: viewshedGraphics,
        scale: sceneView.scale,
        tilt: sceneView.camera.tilt
      }, {
          duration: 1000
        });

      /*
        ステップ：ローディング パネルの非表示
      */
      // processLoader.style.display = "none";
    }

    function errorFunc() {
      processLoader.style.display = "none";
      errorPanel.style.display = "inline";
    }

  });